# tomasrajaolib
[![Updates](https://pyup.io/repos/github/tomasrajao/libpythonpro2/shield.svg)](https://pyup.io/repos/github/tomasrajao/libpythonpro2/)
[![Python 3](https://pyup.io/repos/github/tomasrajao/libpythonpro2/python-3-shield.svg)](https://pyup.io/repos/github/tomasrajao/libpythonpro2/)

Módulo para exemplificar construção de projetos Python no curso Pytools

Nesse curso é ensinado como contribuir com códigos abertos

Link do curso [Python Pro](https://plataforma.dev.pro.br)

Para instalar:
```
python3 -m venv .venv
source .venv/bin/venv
pip install -r requirements-dev.txt
```
Para conferir qualidade de código:
```git
flake8
```

Tópicos a serem abordados:
1. Git
2. Virtualenv
3. Pip